@@ -144,6 +144,7 @@ __all__ = (
     "AssociationFilterTypeDef",
     "AttachmentsSourceTypeDef",
     "AutomationExecutionFilterTypeDef",
+    "BaselineOverrideTypeDef",
     "CancelMaintenanceWindowExecutionResultTypeDef",
     "CommandFilterTypeDef",
     "ComplianceItemEntryTypeDef",
@@ -1982,6 +1983,35 @@ AutomationExecutionFilterTypeDef = TypedDict(
     },
 )
 
+BaselineOverrideTypeDef = TypedDict(
+    "BaselineOverrideTypeDef",
+    {
+        "OperatingSystem": Literal[
+            "WINDOWS",
+            "AMAZON_LINUX",
+            "AMAZON_LINUX_2",
+            "UBUNTU",
+            "REDHAT_ENTERPRISE_LINUX",
+            "SUSE",
+            "CENTOS",
+            "ORACLE_LINUX",
+            "DEBIAN",
+            "MACOS",
+        ],
+        "GlobalFilters": "PatchFilterGroupTypeDef",
+        "ApprovalRules": "PatchRuleGroupTypeDef",
+        "ApprovedPatches": List[str],
+        "ApprovedPatchesComplianceLevel": Literal[
+            "CRITICAL", "HIGH", "MEDIUM", "LOW", "INFORMATIONAL", "UNSPECIFIED"
+        ],
+        "RejectedPatches": List[str],
+        "RejectedPatchesAction": Literal["ALLOW_AS_DEPENDENCY", "BLOCK"],
+        "ApprovedPatchesEnableNonSecurity": bool,
+        "Sources": List["PatchSourceTypeDef"],
+    },
+    total=False,
+)
+
 CancelMaintenanceWindowExecutionResultTypeDef = TypedDict(
     "CancelMaintenanceWindowExecutionResultTypeDef", {"WindowExecutionId": str}, total=False
 )
